# under testing
	Under construction! still adding more functions!
	this is Hemant's work intended to help other developers to develope 
	It is easy to use.
	
# Examples of How To Use 


from HemantDhanwar import EmailServices as es

es.disk_usage('D:/','D:/')

es.email_with_attachhment('HemantDhanwar@lucidmotors.com', 'D:\\H_Work_SPACE\\key.txt', 'HemantDhanwar@lucidmotors.com, kirankumarj@lucidmotors.com, shravankumar@lucidmotors.com', 'D:\\')

disk_usage(path, output_path, SAVE = True)

email_with_attachhment(username, path2key, mail_to, path)

path is where i saved my csv data
